@@ -356,6 +356,12 @@ sub draw_checkbox_cell {
 
 ################################################################################
 
+sub draw_input_cell {
+	drawer_call ('draw_input_cell', @_);	
+}
+
+################################################################################
+
 =head1 draw_tr
 
      .
@@ -1140,6 +1146,18 @@ sub draw_form_field_password {
 
   hidden_value  value.
 
+=item href 
+
+.
+
+=item target
+
+  .
+
+=item a_class
+
+CSS- .
+
 =back
 
 =cut
